#! /usr/bin/env bash

alias @assert=abcli_assert

alias @badge=bluer_ai_badge

alias @browse=bluer_ai_browse

alias @code="abcli_code"

alias @env=bluer_ai_env

alias @eval=abcli_eval

alias @help=bluer_ai_help

alias @hr=abcli_hr

alias @cat=bluer_ai_cat

alias @list=bluer_ai_list

alias @log=abcli_log
alias @error=abcli_log_error
alias @warn=bluer_ai_log_warning

alias @log_list=bluer_ai_log_list

alias @not=abcli_not

alias @open=bluer_ai_open

alias @option=abcli_option
alias @option::int=abcli_option_int
alias @option::choice=abcli_option_choice
alias @option::subset=abcli_option_subset

alias @options=bluer_options

alias @pause=bluer_ai_pause

alias @pylint=bluer_ai_pylint
alias @pytest=bluer_ai_pytest

alias @repeat=bluer_ai_repeat

alias @sleep=bluer_ai_sleep

alias @test=bluer_ai_test

alias @timestamp=abcli_string_timestamp
alias @@timestamp=abcli_string_timestamp_short

alias @today=abcli_string_today

alias @wait=abcli_wait

alias @watch=bluer_ai_watch
